/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef COMPUTATION_PERFORMANCE_ANALYSIS_H
#define COMPUTATION_PERFORMANCE_ANALYSIS_H

#include <string>
#include <QObject>
#include <QToolBar>
#include "Cube.h"


#include "PerformanceAnalysis.h"
#include "PerformanceTest.h"

#include "BranchPredictionPerformanceTest.h"
#include "CachePerformanceTest.h"
#include "L1CacheUtilizationPerformanceTest.h"
#include "L2CacheUtilizationPerformanceTest.h"
#include "L3CacheUtilizationPerformanceTest.h"
#include "VectorizationTest.h"



namespace advisor
{
class ComputationPerformanceAnalysis : public PerformanceAnalysis
{
    Q_OBJECT
private:
    QString BP_ISSUE;
    QString L1_ISSUE;
    QString L2_ISSUE;
    QString L3_ISSUE;

protected:

    BranchPredictionPerformanceTest*   branch_test;
    CachePerformanceTest*              cache_overall;
    L1CacheUtilizationPerformanceTest* l1_cache_test;
    L2CacheUtilizationPerformanceTest* l2_cache_test;
    L3CacheUtilizationPerformanceTest* l3_cache_test;
    VectorizationTest*                 vector_test;

public:
    ComputationPerformanceAnalysis( cube::CubeProxy* _cube );

    virtual
    ~ComputationPerformanceAnalysis();


    inline
    const
    std::string
    name() const
    {
        return "Computation Analysis";
    }


    virtual
    QWidget*
    getToolBar()
    {
        return new QWidget();
    }


    virtual
    QList<AdvisorAdvice>
    getCandidates( const QList<cubegui::TreeItem*>& );


    virtual
    QList<PerformanceTest*>
    getPerformanceTests();

    virtual
    QString
    getAnchorHowToMeasure();

// ------ overview tests ---------

    virtual
    bool
    isActive() const;
};
};

#endif // ADVISER_RATING_WIDGET_H
