/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include <config.h>

#include "KnlLLCMissTest.h"

using namespace advisor;

KnlLLCMissTest::KnlLLCMissTest( cube::CubeProxy* cube ) : PerformanceTest( cube )
{
    setName( tr( "KNL Last Level Cache Miss" ).toUtf8().data() );
    setWeight( 1 );   // need to be adjusted
    maxValue     = 1.;
    knl_llc_miss = cube->getMetric( "LLC_MISSES" );
    if ( knl_llc_miss == NULL )
    {
        setWeight( 0.2 );
        setValue( 0. );
        return;
    }
    cube::metric_pair metric;
    metric.first  = knl_llc_miss;
    metric.second = cube::CUBE_CALCULATE_INCLUSIVE;
    lmetrics.push_back( metric );
}


void
KnlLLCMissTest::applyCnode( const cube::Cnode* cnode, const cube::CalculationFlavour cnf  )
{
    if ( knl_llc_miss == NULL )
    {
        return;
    }
    cube::value_container      inclusive_values;
    cube::value_container      exclusive_values;
    cube::list_of_sysresources lsysres;
    cube::IdIndexMap           metric_id_indices;
    cube->getCallpathSubtreeValues( lmetrics,
                                    lsysres,
                                    *( const_cast<cube::Cnode*>( cnode ) ),
                                    0,
                                    metric_id_indices,
                                    &inclusive_values,
                                    &exclusive_values );
    double knl_llc_miss_value = ( cnf == cube::CUBE_CALCULATE_INCLUSIVE ) ?
                                inclusive_values[ 0 ]->getDouble() :
                                exclusive_values[ 0 ]->getDouble();
    setValue( knl_llc_miss_value );
}

void
KnlLLCMissTest::applyCnode( const cube::list_of_cnodes& cnodes )
{
    if ( knl_llc_miss == NULL )
    {
        return;
    }
    if ( cnodes.size() == 1 )
    {
        applyCnode( cnodes[ 0 ].first, cnodes[ 0 ].second );
    }
    else
    {
        cube::value_container      inclusive_values;
        cube::value_container      exclusive_values;
        cube::list_of_sysresources lsysres;
        cube::IdIndexMap           metric_id_indices;
        cube->getMetricSubtreeValues( cnodes,
                                      lsysres,
                                      *knl_llc_miss,
                                      0,
                                      metric_id_indices,
                                      &inclusive_values,
                                      &exclusive_values );
        double knl_llc_miss_value = inclusive_values[ 0 ]->getDouble();
        setValue( knl_llc_miss_value );
    }
}



const std::string&
KnlLLCMissTest::getCommentText() const
{
    if ( knl_llc_miss == NULL )
    {
        return no_comment;
    }
    else
    {
        return no_comment;
    }
}


// ------ overview tests ---------

bool
KnlLLCMissTest::isActive() const
{
    return knl_llc_miss != NULL;
};

bool
KnlLLCMissTest::isIssue() const
{
    return false;
};
