/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef OVERALL_PERFORMANCE_TEST_H
#define OVERALL_PERFORMANCE_TEST_H

#include <string>
#include "PerformanceTest.h"
#include "OverallComputationPerformanceTest.h"
#include "OverallManagementPerformanceTest.h"

namespace advisor
{
class OverallPerformanceTest : public PerformanceTest
{
private:
    OverallComputationPerformanceTest* computation_overall;
    OverallManagementPerformanceTest*  management_overall;

    double computation_overall_weight;
    double management_overall_weight;



protected:

    inline
    void
    applyCnode( const cube::list_of_cnodes& cnodes   )
    {
        ( void )cnodes;
        calculateOverall();
    }

    inline
    void
    applyCnode( const cube::Cnode*             cnode,
                const cube::CalculationFlavour cnf = cube::CUBE_CALCULATE_INCLUSIVE  )
    {
        ( void )cnode;
        ( void )cnf;
        calculateOverall();
    }


    void
    calculateOverall();

    virtual
    const std::string&
    getCommentText() const;

    inline
    const
    QString
    getHelpUrl()
    {
        return ( isActive() ) ?
               QString::fromStdString( "OverallPerformanceTest" ) :
               QString::fromStdString( "MissingOverallPerformanceTest" );
    }

public:
    OverallPerformanceTest(
        OverallComputationPerformanceTest*,
        OverallManagementPerformanceTest*
        );

    virtual
    ~OverallPerformanceTest()
    {
    };

// ------ overview tests ---------

    bool
    isActive() const
    {
        return true;
    }

    bool
    isIssue() const
    {
        return false;
    }
};
};
#endif // ADVISER_RATING_WIDGET_H
